==> pyglossary_4.5.0.orig.tar.gz: pyglossary-4.5.0/doc/p/dictunformat.md <==
## dictunformat output file

### General Information

| Attribute       | Value                                                                                                      |
| --------------- | ---------------------------------------------------------------------------------------------------------- |
| Name            | Dictunformat                                                                                               |
| snake_case_name | dictunformat                                                                                               |
| Description     | dictunformat output file                                                                                   |
| Extensions      | `.dictunformat`                                                                                            |
| Read support    | Yes                                                                                                        |
| Write support   | No                                                                                                         |
| Single-file     | Yes                                                                                                        |
| Kind            | 📝 text                                                                                                     |
| Sort-on-write   | default_no                                                                                                 |
| Sort key        | (`headword_lower`)                                                                                         |
| Wiki            | [Dictd](https://directory.fsf.org/wiki/Dictd)                                                              |
| Website         | [dictd/dictunformat.1.in - @cheusov/dictd](https://github.com/cheusov/dictd/blob/master/dictunformat.1.in) |

### Read options

| Name     | Default | Type | Comment          |
| -------- | ------- | ---- | ---------------- |
| encoding | `utf-8` | str  | Encoding/charset |



### Dictionary Applications/Tools

| Name & Website                                           | License | Platforms |
| -------------------------------------------------------- | ------- | --------- |
| [dictunformat](https://linux.die.net/man/1/dictunformat) | GPL     | Linux     |

==> pyglossary_5.0.9.orig.tar.gz: pyglossary-5.0.9/doc/p/dictunformat.md <==
## dictunformat output file

### General Information

| Attribute       | Value                                                                                                      |
| --------------- | ---------------------------------------------------------------------------------------------------------- |
| Name            | Dictunformat                                                                                               |
| snake_case_name | dictunformat                                                                                               |
| Description     | dictunformat output file                                                                                   |
| Extensions      | `.dictunformat`                                                                                            |
| Read support    | Yes                                                                                                        |
| Write support   | No                                                                                                         |
| Single-file     | Yes                                                                                                        |
| Kind            | 📝 text                                                                                                     |
| Wiki            | [Dictd](https://directory.fsf.org/wiki/Dictd)                                                              |
| Website         | [dictd/dictunformat.1.in - @cheusov/dictd](https://github.com/cheusov/dictd/blob/master/dictunformat.1.in) |

### Read options

| Name               | Default | Type | Comment                               |
| ------------------ | ------- | ---- | ------------------------------------- |
| encoding           | `utf-8` | str  | Encoding/charset                      |
| headword_separator | `;   `  | str  | separator for headword and alternates |

### Dictionary Applications/Tools

| Name & Website                                           | Source code | License | Platforms | Language |
| -------------------------------------------------------- | ----------- | ------- | --------- | -------- |
| [dictunformat](https://linux.die.net/man/1/dictunformat) | ―           | GPL     | Linux     |          |
